import requests
import json


def handle_to_id(handle: str) -> int:
    Id = requests.post(
        'https://tweeterid.com/ajax.php',
        data={
            'input': handle
        }
    ).content.decode()
    return int(Id)


def id_to_handle(id_: int) -> str:
    handle = requests.post(
        'https://tweeterid.com/ajax.php',
        data={
            'input': str(id_)
        }
    ).content.decode()
    return handle



from distutils.core import setup

setup(
    name='tweeterid',
    version='1.0.0',
    description='Get twitter handles based on user ID\'s and vice-versa via tweeterid.com in python',
    long_description='Get twitter handles based on user ID\'s and vice-versa via tweeterid.com in python',
    author='sl4v',
    author_email='iamsl4v@protonmail.com',
    url='https://github.com/sl4vkek/python-tweeterid',
    packages=['tweeterid'],
    install_requires=['requests'],
    license="WTFPL"
)
